import React from "react";
import ReactDOM from "react-dom";
import { useCallback, useEffect } from "react";
import { useCodeMirror } from "@uiw/react-codemirror";
import { bracketMatching, foldGutter } from "@codemirror/language";
import { closeBrackets } from "@codemirror/autocomplete";
import { history, indentWithTab } from "@codemirror/commands";
import { keymap } from "@codemirror/view";
import { vertexql } from "../vertexql";
const extensions = [
    bracketMatching(),
    closeBrackets(),
    history(),
    foldGutter(),
    keymap.of([indentWithTab]),
    vertexql({
        onShowInDocs(field, type, parentType) {
            alert(`Showing in docs.: Field: ${field}, Type: ${type}, ParentType: ${parentType}`);
        },
        onFillAllFields(view, _query, cursor) {
            console.log("view");
            console.log(view);
            console.log("cursor");
            console.log(cursor);
            alert(`Filling all fields. Query: ${_query}`);
        },
    }),
];
const code = "query: MyQuer {\n get: GetUsers {\n Users {\n userId\n }\n}\n}";
const Editor = () => {
    let divNode;
    const assignRef = useCallback((node) => {
        divNode = node;
    }, []);
    const { setContainer } = useCodeMirror({
        container: divNode,
        extensions,
        value: code,
        theme: "light",
        basicSetup: {
            bracketMatching: true,
            closeBrackets: true,
            foldGutter: true,
            foldKeymap: true,
            history: true,
            highlightActiveLine: false,
            highlightActiveLineGutter: true,
            lineNumbers: true,
        },
        height: "90vh",
    });
    useEffect(() => {
        if (divNode) {
            setContainer(divNode);
        }
    }, [assignRef]);
    return React.createElement("div", { ref: assignRef, style: { height: "90vh" } });
};
ReactDOM.render(React.createElement(Editor, null), document.getElementById("container"));
//# sourceMappingURL=index.js.map