import { EditorView } from '@codemirror/view';
import * as _codemirror_state from '@codemirror/state';
import { Text, Extension, StateField, EditorState } from '@codemirror/state';
import { CompletionContext, Completion } from '@codemirror/autocomplete';
import { CompletionItem } from 'vertexql-language-service';
import { LRLanguage, LanguageSupport } from '@codemirror/language';

declare const fillAllFieldsCommands: (view: EditorView) => boolean;
declare const showInDocsCommand: (view: EditorView) => boolean;

declare const completion: _codemirror_state.Extension;

declare function posToOffset(doc: Text, pos: IPosition): number;
declare function offsetToPos(doc: Text, offset: number): Position;
interface IPosition {
    line: number;
    character: number;
    setLine(line: number): void;
    setCharacter(character: number): void;
    lessThanOrEqualTo(position: IPosition): boolean;
}
declare class Position implements IPosition {
    line: number;
    character: number;
    constructor(line: number, character: number);
    setLine(line: number): void;
    setCharacter(character: number): void;
    lessThanOrEqualTo(position: IPosition): boolean;
}
declare const isMetaKeyPressed: (e: MouseEvent) => boolean;

interface VqlExtensionsOptions {
    showErrorOnInvalidSchema?: boolean;
    onShowInDocs?: (field?: string, type?: string, parentType?: string) => void;
    onFillAllFields?: (view: EditorView, query: string, cursor: Position) => void;
    onCompletionInfoRender?: (gqlCompletionItem: CompletionItem, ctx: CompletionContext, item: Completion) => Node | Promise<Node | null> | null;
}

declare function vertexql(opts?: VqlExtensionsOptions): Extension[];

declare const jump: _codemirror_state.Extension;

declare const vertexqlLanguage: LRLanguage;
declare function vertexqlLanguageSupport(): LanguageSupport;

declare const lint: Extension;

declare const optionsStateField: StateField<void | VqlExtensionsOptions>;
declare const updateOpts: (view: EditorView, opts?: VqlExtensionsOptions) => void;
declare const getOpts: (state: EditorState) => void | VqlExtensionsOptions;
declare const stateExtensions: (opts?: VqlExtensionsOptions) => _codemirror_state.Extension[];

export { type IPosition, Position, completion, fillAllFieldsCommands, getOpts, isMetaKeyPressed, jump, lint, offsetToPos, optionsStateField, posToOffset, showInDocsCommand, stateExtensions, updateOpts, vertexql, vertexqlLanguage, vertexqlLanguageSupport };
