import { parser } from "./Grammar/vertexql-lr-parser.js";
import { LRLanguage, LanguageSupport, indentNodeProp, foldNodeProp, foldInside, delimitedIndent, } from "@codemirror/language";
import { styleTags, tags as t } from "@lezer/highlight";
const nodesWithBraces = "{";
const keywords = "_take _skip _sort get view update delete _lt _lte _gt _gte";
const punctuations = "( ) { } : [ ]";
export const vertexqlLanguage = LRLanguage.define({
    parser: parser.configure({
        props: [
            styleTags({
                BooleanValue: t.bool,
                Description: t.string,
                StringValue: t.string,
                LineComment: t.lineComment,
                IntValue: t.integer,
                FloatValue: t.float,
                EnumValue: t.special(t.name),
                NullValue: t.null,
                DirectiveName: t.modifier,
                [keywords]: t.keyword,
                OperationType: t.definitionKeyword,
                FieldName: t.propertyName,
                Field: t.propertyName,
                ArgumentAttributeName: t.attributeName,
                Name: t.atom,
                "( )": t.paren,
                "{ }": t.brace,
                ",": t.separator,
                [punctuations]: t.punctuation,
            }),
            indentNodeProp.add({
                [nodesWithBraces]: delimitedIndent({
                    closing: "}",
                    align: true,
                }),
            }),
            foldNodeProp.add({
                [nodesWithBraces]: foldInside,
            }),
        ],
    }),
    languageData: {
        commentTokens: { line: "#" },
        indentOnInput: /^\s*(\{|\})$/,
    },
});
export function vertexqlLanguageSupport() {
    return new LanguageSupport(vertexqlLanguage);
}
//# sourceMappingURL=language.js.map